<?php

namespace Restaurant\Eatery\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Restaurant\Eatery\Models\Eatery;

class EateryPolicy
{

    /**
     * Determine if the given user can view the eatery.
     *
     * @param UserPolicyInterface $authUser
     * @param Eatery $eatery
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Eatery $eatery)
    {
        if ($authUser->canDo('eatery.eatery.view') && $authUser->isAdmin()) {
            return true;
        }

        return $eatery->user_id == user_id() && $eatery->user_type == user_type();
    }

    /**
     * Determine if the given user can create a eatery.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('eatery.eatery.create');
    }

    /**
     * Determine if the given user can update the given eatery.
     *
     * @param UserPolicyInterface $authUser
     * @param Eatery $eatery
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Eatery $eatery)
    {
        if ($authUser->canDo('eatery.eatery.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $eatery->user_id == user_id() && $eatery->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given eatery.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Eatery $eatery)
    {
        return $eatery->user_id == user_id() && $eatery->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given eatery.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Eatery $eatery)
    {
        if ($authUser->canDo('eatery.eatery.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given eatery.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Eatery $eatery)
    {
        if ($authUser->canDo('eatery.eatery.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
